@@ -39,7 +39,7 @@ class EnrichClient(NamespacedClient):
         """
         Deletes an existing enrich policy and its enrich index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/delete-enrich-policy-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/delete-enrich-policy-api.html>`_
 
         :param name: The name of the enrich policy
         """
@@ -76,7 +76,7 @@ class EnrichClient(NamespacedClient):
         """
         Creates the enrich index for an existing enrich policy.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/execute-enrich-policy-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/execute-enrich-policy-api.html>`_
 
         :param name: The name of the enrich policy
         :param wait_for_completion: Should the request should block until the execution
@@ -116,7 +116,7 @@ class EnrichClient(NamespacedClient):
         """
         Gets information about an enrich policy.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/get-enrich-policy-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/get-enrich-policy-api.html>`_
 
         :param name: A comma-separated list of enrich policy names
         """
@@ -153,15 +153,17 @@ class EnrichClient(NamespacedClient):
         human: t.Optional[bool] = None,
         match: t.Optional[t.Mapping[str, t.Any]] = None,
         pretty: t.Optional[bool] = None,
+        range: t.Optional[t.Mapping[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Creates a new enrich policy.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/put-enrich-policy-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/put-enrich-policy-api.html>`_
 
         :param name: The name of the enrich policy
         :param geo_match:
         :param match:
+        :param range:
         """
         if name in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'name'")
@@ -180,6 +182,8 @@ class EnrichClient(NamespacedClient):
             __body["match"] = match
         if pretty is not None:
             __query["pretty"] = pretty
+        if range is not None:
+            __body["range"] = range
         __headers = {"accept": "application/json", "content-type": "application/json"}
         return await self.perform_request(  # type: ignore[return-value]
             "PUT", __path, params=__query, headers=__headers, body=__body
@@ -200,7 +204,7 @@ class EnrichClient(NamespacedClient):
         Gets enrich coordinator statistics and information about enrich policies that
         are currently executing.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/enrich-stats-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/enrich-stats-api.html>`_
         """
         __path = "/_enrich/_stats"
         __query: t.Dict[str, t.Any] = {}
