@@ -41,7 +41,7 @@ class MigrationClient(NamespacedClient):
         that use deprecated features that will be removed or changed in the next major
         version.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/migration-api-deprecation.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/migration-api-deprecation.html>`_
 
         :param index: Comma-separate list of data streams or indices to check. Wildcard
             (*) expressions are supported.
@@ -78,7 +78,7 @@ class MigrationClient(NamespacedClient):
         """
         Find out whether system features need to be upgraded or not
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/migration-api-feature-upgrade.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/migration-api-feature-upgrade.html>`_
         """
         __path = "/_migration/system_features"
         __query: t.Dict[str, t.Any] = {}
@@ -109,7 +109,7 @@ class MigrationClient(NamespacedClient):
         """
         Begin upgrades for system features
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/migration-api-feature-upgrade.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/migration-api-feature-upgrade.html>`_
         """
         __path = "/_migration/system_features"
         __query: t.Dict[str, t.Any] = {}
